@@ -41,7 +41,7 @@ class AgentSection(BaseModel):
 
 class ServiceSection(BaseModel):
     host: str = "https://app.reliably.com"
-    token: SecretStr
+    token: SecretStr | None
 
 
 class LogSection(BaseModel):
@@ -50,7 +50,7 @@ class LogSection(BaseModel):
 
 
 class Settings(BaseSettings):
-    service: ServiceSection | None
+    service: ServiceSection = ServiceSection()
     agent: AgentSection | None
     organization: OrgSection | None
     plan: PlanSection | None
